==> nisje-wp-plugin-blogs-in-groups-7.1.3.zip: blogs-in-groups/post-types/post-type-blogs-group.php <==
<?php
/**
 * Set up group blogs post type
 *
 * @package Nisje
 */

defined( 'ABSPATH' ) || die( 'Shame on you' );

$cap = nisje_get_setting( 'capability_key_group', 'blogs' );

$args = apply_filters(
	'nisje_post_type_blogs_group_args', [
		'labels'                => [
			'name'          => esc_html__( 'Group Blogs', 'nisje-blogs-in-groups' ),
			'singular_name' => esc_html__( 'Group Blogs', 'nisje-blogs-in-groups' ),
		],
		'public'                => true,
		'publicly_queryable'    => true,
		'exclude_from_search'   => false,
		'show_in_admin_bar'     => false,
		'show_in_nav_menus'     => false,
		'can_export'            => false,
		'show_ui'               => false,
		'query_var'             => false,
		'has_archive'           => false,
		'rewrite'               => false,
		'capability_type'       => $cap,
		'capabilities'          => [
			'create_posts'     => "create_{$cap}s",
			'delete_posts'     => "delete_{$cap}s",
			'upload_files_cpt' => "upload_files_{$cap}",
		],
		'map_meta_cap'          => true,
		'hierarchical'          => false,
		'menu_position'         => null,
		'menu_icon'             => 'dashicons-media-text',
		'supports'              => [
			'title',
			'revisions',
			'editor',
			'comments',
			'thumbnail',
			'author',
			'excerpt',
		],
		'show_in_rest'          => true,
		'rest_base'             => nisje_get_setting( 'post_type_rest_endpoint_group', 'blogs' ),
		'rest_controller_class' => '\\Dekode\\Nisje\\Components\\Rest\\Base_Group_Post_Controller',
	]
);

register_post_type( nisje_get_setting( 'post_type_name_group', 'blogs' ), $args ); // phpcs:ignore

==> nisje-wp-plugin-blogs-in-groups-8.0.6.zip: blogs-in-groups/post-types/post-type-blogs-group.php <==
<?php
/**
 * Set up group blogs post type
 *
 * @package Nisje
 */

defined( 'ABSPATH' ) || die( 'Shame on you' );

$cap = nisje_get_setting( 'capability_key_group', 'blogs' );

$args = apply_filters(
	'nisje_post_type_blogs_group_args', [
		'labels'                => [
			'name'          => esc_html__( 'Group Blogs', 'nisje' ),
			'singular_name' => esc_html__( 'Group Blogs', 'nisje' ),
		],
		'public'                => true,
		'publicly_queryable'    => true,
		'exclude_from_search'   => false,
		'show_in_admin_bar'     => false,
		'show_in_nav_menus'     => false,
		'can_export'            => false,
		'show_ui'               => false,
		'query_var'             => false,
		'has_archive'           => false,
		'rewrite'               => false,
		'capability_type'       => $cap,
		'capabilities'          => [
			'create_posts'     => "create_{$cap}s",
			'delete_posts'     => "delete_{$cap}s",
			'upload_files_cpt' => "upload_files_{$cap}",
		],
		'map_meta_cap'          => true,
		'hierarchical'          => false,
		'menu_position'         => null,
		'menu_icon'             => 'dashicons-media-text',
		'supports'              => [
			'title',
			'revisions',
			'editor',
			'comments',
			'thumbnail',
			'author',
			'excerpt',
		],
		'show_in_rest'          => true,
		'rest_base'             => nisje_get_setting( 'post_type_rest_endpoint_group', 'blogs' ),
		'rest_controller_class' => '\\Dekode\\Nisje\\Components\\Rest\\Base_Group_Post_Controller',
	]
);

register_post_type( nisje_get_setting( 'post_type_name_group', 'blogs' ), $args ); // phpcs:ignore
